package com.ningdatech.pmapi.common.statemachine.util;

import com.ningdatech.pmapi.common.constant.ProjectDeclareConstants;
import com.ningdatech.pmapi.common.constant.StateMachineHeaderNameConstants;
import com.ningdatech.pmapi.common.statemachine.builder.ProjectDeclareStateMachineBuilder;
import com.ningdatech.pmapi.projectlib.enums.ProjectStatusChangeEvent;
import com.ningdatech.pmapi.projectlib.enums.ProjectStatusEnum;
import com.ningdatech.pmapi.projectlib.model.entity.Project;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.messaging.Message;
import org.springframework.messaging.support.MessageBuilder;
import org.springframework.statemachine.StateMachine;
import org.springframework.statemachine.persist.StateMachinePersister;

import javax.annotation.Resource;

/**
 * 状态机工具类
 *
 * @author CMM
 * @since 2023/02/07 22:49
 */
@Slf4j
public class StateMachineUtils {

    private static final String PROJECT_DECLARE = StateMachineHeaderNameConstants.PROJECT_DECLARE;

    @Autowired
    private ProjectDeclareStateMachineBuilder projectDeclareStateMachineBuilder;

    @Resource(name = "projectDeclareStateMachinePersister")
    private StateMachinePersister projectDeclareStateMachinePersister;

    public void execute(Project project, ProjectStatusChangeEvent event) throws Exception{
        log.debug("调用状态机前的项目状态为>>>>>>>>>>{}"+project.getProjectStatusSecond());
        //获取TO状态机
        StateMachine<ProjectStatusEnum, ProjectStatusChangeEvent> stateMachine = projectDeclareStateMachineBuilder.build();
        Message message = MessageBuilder.withPayload(event).setHeader(PROJECT_DECLARE, project).build();
        //初始化状态机
        projectDeclareStateMachinePersister.restore(stateMachine,project);
        stateMachine.sendEvent(message);
        log.debug("调用状态机后的项目状态为>>>>>>>>>>{}"+project.getProjectStatusSecond());
    }

    /**
     * 判断
     * @param project
     * @return boolean
     * @author CMM
     * @since 2023/02/07 17:13
     */
    public static boolean JudgeDeclareAmount(Project project) {
        int flag = project.getDeclareAmount().compareTo(ProjectDeclareConstants.Number.DECLARE_AMOUNT_JUDGEMENT);
        if (flag > 0 || flag == 0){
            return true;
        }
        return false;
    }

    /**
     * 判断项目建设层级是否为市级项目
     * @param project
     * @return boolean
     * @author CMM
     * @since 2023/02/07 17:05
     */
    public static boolean isCityProject(Project project) {
        if (ProjectDeclareConstants.Number.CITY_BUILD_LEVEL.equals(project.getBuildLevel()) ||
                ProjectDeclareConstants.Number.CITY_SELF_BUILD_LEVEL.equals(project.getBuildLevel())){
            return true;
        }
        return false;
    }
}
