package com.ningdatech.pmapi.projectlib.enums;
/**
 *  项目状态改变事件
 * @return
 * @author CMM
 * @since 2023/02/07 9:22
 */
public enum ProjectStatusChangeEvent {
    /**
     * 项目申报暂存(项目状态进入：待申报)
     */
    PROJECT_APPLICATION_HOLD,
    /**
     * 项目申报提交(项目状态进入：单位内部审核中)
     */
    PROJECT_APPLICATION_SUBMIT,
    /**
     * 单位内部审核驳回(项目状态进入：单位内部审核不通过)
     */
    UNDER_INTERNAL_REJECT,
    /**
     * 单位内部审核通过(项目状态进入：待预审)
     */
    UNDER_INTERNAL_PASS,
    /**
     * 预审申报(项目状态进入：待预审选择，有判断条件：市级项目且申报金额大于1000万项目状态变为：省级部门联审中；否则项目状态变为：预审中)
     */
    PRELIMINARY_REVIEW_DECLARE,
    /**
     * 省级部门联审不通过(项目状态变为：省级部门联审不通过)
     */
    PROVINCIAL_DEPARTMENT_REVIEW_REJECT,
    /**
     * 省级部门联审通过(项目状态变为：预审中)
     */
    PROVINCIAL_DEPARTMENT_REVIEW_PASS,
    /**
     * 预审驳回(项目状态变为：预审不通过)
     */
    PRELIMINARY_REVIEW_REJECT,
    /**
     * 预审通过(项目状态变为：部门联审中)
     */
    PRELIMINARY_REVIEW_PASS,
    /**
     * 部门联审驳回(项目状态变为：部门联审不通过)
     */
    DEPARTMENT_UNITED_REVIEW_REJECT,
    /**
     * 部门联审通过(项目状态变为：年度计划中)
     */
    DEPARTMENT_UNITED_REVIEW_PASS,
    /**
     * 年度计划暂缓(项目状态变为：被暂缓)
     */
    ANNUAL_PLAN_SUSPEND,
    /**
     * 年度计划项目开启方案申报(项目状态变为：方案待申报)
     */
    ANNUAL_PLAN_PROJECT_OPEN_PLAN_DECLARE,
    /**
     * 申报方案(项目状态变为：方案评审中)
     */
    DECLARE_PLAN,
    /**
     * 方案评审驳回(项目状态变为：方案评审不通过)
     */
    PLAN_REVIEW_REJECT,
    /**
     * 方案评审通过(项目状态变为：待立项批复)
     */
    PLAN_REVIEW_PASS,
    /**
     * 立项批复(项目状态变为：已立项-待采购)
     */
    PROJECT_APPROVAL,
    /**
     * 采购备案(项目状态变为：建设中)
     */
    PURCHASE_PUT_ON_RECORD,
    /**
     * 初验备案(项目状态变为：待终验)
     */
    PRELIMINARY_ACCEPTANCE_PUT_ON_RECORD,
    /**
     * 终验申请(项目状态变为：终验审核中)
     */
    FINAL_ACCEPTANCE_APPLICATION,
    /**
     * 终验审核不通过(项目状态变为：终验审核不通过)
     */
    FINAL_ACCEPTANCE_REJECT,
    /**
     * 终验审核通过(项目状态变为：已归档)
     */
    FINAL_ACCEPTANCE_PASS,

    // 下个节点还未提交审核意见时，流程发起人和前一个审核人可以点击撤回

    /**
     * 单位内部审核中时被撤回(项目状态进入：待申报)
     */
    UNDER_INTERNAL_WITHDRAW,
    /**
     * 待预审时被撤回(项目状态进入：单位内部审核中)
     */
    PENDING_PREQUALIFICATION_WITHDRAW,
    /**
     * 省级部门联审中时被撤回(项目状态进入：待预审)
     */
    JOINT_REVIEW_BY_PROVINCIAL_DEPARTMENTS_WITHDRAW,
    /**
     *  预审中时被撤回(项目状态进入：待预审选择，，有判断条件：市级项目且申报金额大于1000万项目状态变为：省级部门联审中；否则项目状态变为：预审中)
     */
    PRE_APPLYING_WITHDRAW,
    /**
     *  部门联审中时被撤回(项目状态进入：预审中)
     */
    DEPARTMENT_JOINT_REVIEW_WITHDRAW,
    /**
     *  年度计划中时被撤回(项目状态进入：部门联审中)
     */
    IN_THE_ANNUAL_PLAN_WITHDRAW,
    /**
     * 方案待申报时被撤回(项目状态进入：年度计划中)
     */
    PLAN_TO_DECLARE_WITHDRAW,
    /**
     * 方案评审中时被撤回(项目状态进入：方案待申报)
     */
    SCHEME_UNDER_REVIEW_WITHDRAW,
    /**
     * 待立项批复时被撤回(项目状态进入：方案评审中)
     */
    TO_BE_APPROVED_WITHDRAW,
    /**
     * 待采购时被撤回(项目状态进入：待立项批复)
     */
    TO_BE_PURCHASED_WITHDRAW,
    /**
     *  建设中时被撤回(项目状态进入：待采购)
     */
    UNDER_CONSTRUCTION_WITHDRAW,
    /**
     * 待终验时被撤回(项目状态进入：建设中)
     */
    TO_BE_FINALLY_INSPECTED_WITHDRAW,
    /**
     *  终验审核中时被撤回(项目状态进入：待终验)
     */
    FINAL_ACCEPTANCE_IS_UNDER_REVIEW_WITHDRAW,

}
